<?php

return [
    'profiles' => [
        'qvc_standard' => [
            'name' => 'QVC Standard CSV',
            'minMatchedColumns' => 4,
            'requiredTargets' => [
                'cartsbe.ordernumber',
                'cartlines.stock_code',
                'cartlines.qty',
            ],
            'columns' => [
                'Order Number' => 'cartsbe.ordernumber',
                'Order No' => 'cartsbe.ordernumber',
                'Order Ref' => 'cartsbe.ordernumber',
                'PO Number' => 'cartsbe.porderref',
                'PO' => 'cartsbe.porderref',
                'Account Code' => 'cartsbe.account_code',
                'Customer Name' => 'cartsbe.name',
                'Name' => 'cartsbe.name',
                'Email' => 'cartsbe.email',
                'Contact' => 'cartsbe.contact',
                'Telephone' => 'cartsbe.telephone',
                'Phone' => 'cartsbe.telephone',
                'Postcode' => 'cartsbe.postcode',
                'Delivery Address' => 'cartsbe.deliveryaddress',
                'Billing Address' => 'cartsbe.billingaddress',
                'Message' => 'cartsbe.message',
                'Delivery Notes' => 'cartsbe.delivery_notes',
                'Shipping Method' => 'cartsbe.shippingmethod',
                'Full Address Shipping' => 'cartsbe.fulladdresses.shipping',
                'Full Shipping Address' => 'cartsbe.fulladdresses.shipping',
                'Shipping Name' => 'cartsbe.fulladdresses.shipping.name',
                'Shipping First Name' => 'cartsbe.fulladdresses.shipping.firstname',
                'Shipping Last Name' => 'cartsbe.fulladdresses.shipping.lastname',
                'Shipping Company Name' => 'cartsbe.fulladdresses.shipping.companyname',
                'Shipping Contact' => 'cartsbe.fulladdresses.shipping.contact',
                'Shipping Email' => 'cartsbe.fulladdresses.shipping.email',
                'Shipping Address 1' => 'cartsbe.fulladdresses.shipping.address1',
                'Shipping Address 2' => 'cartsbe.fulladdresses.shipping.address2',
                'Shipping Address 3' => 'cartsbe.fulladdresses.shipping.address3',
                'Shipping Town' => 'cartsbe.fulladdresses.shipping.town',
                'Shipping City' => 'cartsbe.fulladdresses.shipping.town',
                'Shipping County' => 'cartsbe.fulladdresses.shipping.county',
                'Shipping State' => 'cartsbe.fulladdresses.shipping.county',
                'Shipping Country' => 'cartsbe.fulladdresses.shipping.country',
                'Shipping Postcode' => 'cartsbe.fulladdresses.shipping.postcode',
                'Shipping Telephone' => 'cartsbe.fulladdresses.shipping.telephone',
                'Shipping Phone' => 'cartsbe.fulladdresses.shipping.telephone',
                'Shipping Fax' => 'cartsbe.fulladdresses.shipping.fax',
                'Payment Method' => 'cartsbe.paymentmethod',
                'Status' => 'cartsbe.status',
                'SKU' => 'cartlines.stock_code',
                'Stock Code' => 'cartlines.stock_code',
                'Product Name' => 'cartlines.product_name',
                'Product Description' => 'cartlines.product_description',
                'Quantity' => 'cartlines.qty',
                'Qty' => 'cartlines.qty',
                'Unit Price' => 'cartlines.price',
                'Price' => 'cartlines.price',
                'Price Ex VAT' => 'cartlines.price_exvat',
                'Discount' => 'cartlines.disc',
                'Currency' => 'cartlines.currency_code',
                'Currency Code' => 'cartlines.currency_code',
            ],
        ],
    ],
];
